# Table of Contents

- [configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias](<./configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Configuring SSO with SAP Cloud Identity Services - Identity Authentication Service (IAS)](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS.md>)
  - [Prerequisites](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Prerequisites.md>)
  - [Step 1: Get SSO Metadata from IAS](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Step-1-Get-SSO-Metadata-from-IAS.md>)
  - [Step 2: Create a SAML Application](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Step-2-Create-a-SAML-Application.md>)
  - [Step 3: Configure SAML Settings](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Step-3-Configure-SAML-Settings.md>)
  - [Step 4: Configure Attribute Mapping](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Step-4-Configure-Attribute-Mapping.md>)
  - [(Optional) Step 5: Configure Role Attributes](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Optional-Step-5-Configure-Role-Attributes.md>)
  - [Step 6: Verify SSO Configuration](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Step-6-Verify-SSO-Configuration.md>)
  - [Was this page helpful?](<./Configuring-SSO-with-SAP-Cloud-Identity-Services---Identity-Authentication-Service-IAS/Was-this-page-helpful.md>)
